==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/ENERGYSTARTRANSACTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ENERGYSTARTRANSACTIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ENERGYSTARTRANSACTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENERGYSTARTRANSACTIONCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ENERGYSTARTRANSACTIONID_Type", propOrder = {
    "energystartransactioncode"
})
public class ENERGYSTARTRANSACTIONID_Type {

    @XmlElement(name = "ENERGYSTARTRANSACTIONCODE", required = true)
    protected String energystartransactioncode;

    /**
     * Obtient la valeur de la propriété energystartransactioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENERGYSTARTRANSACTIONCODE() {
        return energystartransactioncode;
    }

    /**
     * Définit la valeur de la propriété energystartransactioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENERGYSTARTRANSACTIONCODE(String value) {
        this.energystartransactioncode = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/ENERGYSTARTRANSACTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ENERGYSTARTRANSACTIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ENERGYSTARTRANSACTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENERGYSTARTRANSACTIONCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ENERGYSTARTRANSACTIONID_Type", propOrder = {
    "energystartransactioncode"
})
public class ENERGYSTARTRANSACTIONID_Type {

    @XmlElement(name = "ENERGYSTARTRANSACTIONCODE", required = true)
    protected String energystartransactioncode;

    /**
     * Gets the value of the energystartransactioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENERGYSTARTRANSACTIONCODE() {
        return energystartransactioncode;
    }

    /**
     * Sets the value of the energystartransactioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENERGYSTARTRANSACTIONCODE(String value) {
        this.energystartransactioncode = value;
    }

}
